#
# spec file for package python-glad2
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pythons python3
Name:           python-glad2
Version:        2.0.8
Release:        1.0.2.1.sr20250402
Summary:        Command line utility to load/generate multi-language GL/GLES/EGL/GLX/WGL code
License:        MIT
URL:            https://github.com/Dav1dde/glad
Source0:        https://files.pythonhosted.org/packages/source/g/glad2/glad2-%{version}.tar.gz
Source1:        python-glad2-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools > 61.0
BuildRequires:  python3-wheel
Requires:       python3-Jinja2
Provides:       glad
Obsoletes:      python311-glad2 < %{version}
Obsoletes:      python312-glad2 < %{version}
Obsoletes:      python313-glad2 < %{version}
BuildArch:      noarch
%python_subpackages

%description
Glad is a command line utility to generate GL/GLES/EGL/GLX/WGL loader code
based on the official specifications for using as bundled source code with
apps.

%prep
%autosetup -n glad2-%{version}
sed -Ei "1{\@%{_bindir}/env python@d}" glad/__main__.py

%build
%pyproject_wheel

%install
%pyproject_install
%fdupes %{buildroot}%{python3_sitelib}

%files %{python_files}
%doc README.md
%license LICENSE
%{_bindir}/glad
%{python3_sitelib}/glad/
%{python3_sitelib}/glad2-%{version}*.*-info

%changelog
* Fri Apr 18 2025 Atri Bhattacharya <badshah400@gmail.com>
- Restore mistakenly removed %%python_subpackages macro that
  prevented package renaming as python3-glad2.
* Wed Apr 16 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.8:
  * files: updates to latest specifications.
  * rust: replace static mut references with addr_of.
  * Replace setup.py with pyproject.toml [gh#Dav1dde/glad##490].
- Rework package:
  * Drop support for multiple python versions and build only for
    default python3; this is a command line app, not a python
    library.
  * Switch to pyproject_* macros for build.
  * Keep zero-sized template code which is used and filled in when
    producing generated code.
  * Add Provides: glad to package.
  * Drop python-Jinja2 from BuildRequires; run-time but not build
    dependency.
  * Drop python-setuptools from Requires.
  * Delete unnecessary hashbang from a non-executable file.
  * Drop update-alternatives post scripts and related requires.
  * Add Obsoletes against current pythons packages.
* Wed Jun 19 2024 Dirk Müller <dmueller@suse.com>
- update to 2.0.6:
  * Fix eglplatform in header only build not correctly replacing
    the khrplatform include
  * Fix compile warning when GLAD_GLES2_USE_SYSTEM_EGL=1
  * Fix: Use include instead of find_package for CMake config
  * c: don't warn on undefined GLAD_GLES2_USE_SYSTEM_EGL
- update to 2.0.5:
  * Fix missing Vulkan video headers
  * Use FindPython instead of FindPythonInterp
  * Add --version option to command-line interface
  * Remove one duplicated check for glGetString(GL_VERSION)
  * Fix extensions loading and parsing
  * Provide CMake package
* Wed Sep 20 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue Feb 28 2023 Callum Farmer <gmbr3@opensuse.org>
- Correct BR from python3-jinja2 to python3-Jinja2, fixes
  dependency resolving on older distros
* Wed Oct 26 2022 Niklas Haas <obs@haasn.xyz>
- Add missing run-time dependency on python-setuptools
* Wed Oct 26 2022 Niklas Haas <obs@haasn.xyz>
- Update to glad v2.0.1
* Fri Oct 21 2022 Niklas Haas <obs@haasn.xyz>
- Initial package, based upon the initial release of glad v2.0.0
